# Drivnal
Linux backup utility with web interface. Visit
[drivnal.com](http://drivnal.com/) for more info.

-------------------------------------------------------------------------------

Copyright (c) 2013 Zachary Huff

Drivnal is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Drivnal is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Drivnal. If not, see <http://www.gnu.org/licenses/>.
